package Bencher::ScenarioR::TextTableModules;

our $VERSION = 0.07; # VERSION

our $results = [
  [
    200,
    "OK",
    [
      {
        errors => 0.00054,
        participant => "Text::ANSITable",
        rate => 2.1,
        samples => 20,
        time => 480,
        vs_slowest => 1,
      },
      {
        errors => 0.00033,
        participant => "Text::ASCIITable",
        rate => 4.5,
        samples => 21,
        time => 220,
        vs_slowest => 2.1,
      },
      {
        errors => 9.9e-05,
        participant => "Text::Table::TinyColorWide",
        rate => 10,
        samples => 21,
        time => 99.9,
        vs_slowest => 4.76,
      },
      {
        errors => 0.00016,
        participant => "Text::FormatTable",
        rate => 12,
        samples => 20,
        time => 83,
        vs_slowest => 5.7,
      },
      {
        errors => 6.8e-05,
        participant => "Text::Table::TinyWide",
        rate => 15,
        samples => 20,
        time => 66,
        vs_slowest => 7.2,
      },
      {
        errors => 3.6e-05,
        participant => "Text::TabularDisplay",
        rate => 29,
        samples => 20,
        time => 35,
        vs_slowest => 14,
      },
      {
        errors => 2.5e-05,
        participant => "Text::Table::TinyColor",
        rate => 44,
        samples => 20,
        time => 23,
        vs_slowest => 21,
      },
      {
        errors => 8.5e-05,
        participant => "Text::MarkdownTable",
        rate => 71,
        samples => 21,
        time => 14,
        vs_slowest => 34,
      },
      {
        errors => 9.6e-06,
        participant => "Text::Table",
        rate => 98.6,
        samples => 20,
        time => 10.1,
        vs_slowest => 46.9,
      },
      {
        errors => 4.4e-05,
        participant => "Text::Table::CSV",
        rate => 160,
        samples => 20,
        time => 6.1,
        vs_slowest => 78,
      },
      {
        errors => 7.4e-06,
        participant => "Text::Table::Org",
        rate => 220,
        samples => 20,
        time => 4.6,
        vs_slowest => 100,
      },
      {
        errors => 6.9e-06,
        participant => "Text::Table::Tiny",
        rate => 250,
        samples => 20,
        time => 4,
        vs_slowest => 120,
      },
    ],
    {
      "func.bencher_args"    => {
                                  action => "bench",
                                  note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                  scenario_module => "TextTableModules",
                                },
      "func.bencher_version" => undef,
      "func.cpu_info"        => [
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 0,
                                    speed                        => 2926.835,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 1,
                                    speed                        => 2900.921,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 2,
                                    speed                        => 2283.464,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 3,
                                    speed                        => 2779.343,
                                    stepping                     => 7,
                                  },
                                ],
      "func.elapsed_time"    => 28.1816189289093,
      "func.module_startup"  => undef,
      "func.module_versions" => {
                                  "Bencher::Scenario::TextTableModules" => undef,
                                  "Benchmark::Dumb"                     => "0.10",
                                  "Devel::Platform::Info"               => 0.16,
                                  "perl"                                => "v5.24.0",
                                  "Sys::Info"                           => 0.78,
                                  "Sys::Load"                           => 0.2,
                                  "Text::ANSITable"                     => 0.48,
                                  "Text::ASCIITable"                    => "0.20",
                                  "Text::FormatTable"                   => 1.03,
                                  "Text::MarkdownTable"                 => "0.3.1",
                                  "Text::Table"                         => 1.131,
                                  "Text::Table::CSV"                    => 0.01,
                                  "Text::Table::Org"                    => 0.02,
                                  "Text::Table::Tiny"                   => 0.04,
                                  "Text::Table::TinyColor"              => 0.002,
                                  "Text::Table::TinyColorWide"          => 0.001,
                                  "Text::Table::TinyWide"               => 0.001,
                                  "Text::TabularDisplay"                => 1.38,
                                },
      "func.note"            => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"         => ["participant", [0 .. 11], "perl", ["perl"]],
      "func.platform_info"   => {
                                  archname => "x86_64",
                                  codename => "jessie",
                                  is32bit  => 0,
                                  is64bit  => 1,
                                  kernel   => "linux-3.16.0-4-amd64",
                                  kname    => "Linux",
                                  kvers    => "3.16.0-4-amd64",
                                  osflag   => "linux",
                                  oslabel  => "Debian",
                                  osname   => "GNU/Linux",
                                  osvers   => "8.0",
                                  source   => {
                                                "cat /etc/.issue" => "",
                                                "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
                                                "uname -m"        => "x86_64",
                                                "uname -o"        => "GNU/Linux",
                                                "uname -r"        => "3.16.0-4-amd64",
                                                "uname -s"        => "Linux",
                                              },
                                },
      "func.precision"       => 0,
      "func.scenario_module" => "Bencher::Scenario::TextTableModules",
      "func.sysload_after"   => [1.02, 0.65, 0.6],
      "func.sysload_before"  => [0.82, 0.57, 0.57],
      "func.time_end"        => 1476889054.92332,
      "func.time_factor"     => 1000,
      "func.time_start"      => 1476889026.7417,
      "table.field_aligns"   => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"    => [undef, "/s", "ms"],
      "table.fields"         => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors => 4.5e-05,
        participant => "Text::ANSITable",
        rate => 19.1,
        samples => 20,
        time => 52.3,
        vs_slowest => 1,
      },
      {
        errors => 2e-05,
        participant => "Text::ASCIITable",
        rate => 45.3,
        samples => 20,
        time => 22.1,
        vs_slowest => 2.37,
      },
      {
        errors => 4.5e-06,
        participant => "Text::Table::TinyColorWide",
        rate => 94.9,
        samples => 20,
        time => 10.5,
        vs_slowest => 4.97,
      },
      {
        errors => 9.7e-06,
        participant => "Text::FormatTable",
        rate => 102,
        samples => 22,
        time => 9.8,
        vs_slowest => 5.34,
      },
      {
        errors => 6.7e-06,
        participant => "Text::Table::TinyWide",
        rate => 143,
        samples => 20,
        time => 7,
        vs_slowest => 7.47,
      },
      {
        errors => 5.2e-06,
        participant => "Text::TabularDisplay",
        rate => 190,
        samples => 21,
        time => 5.2,
        vs_slowest => 10,
      },
      {
        errors => 9.4e-06,
        participant => "Text::MarkdownTable",
        rate => 310,
        samples => 21,
        time => 3.2,
        vs_slowest => 16,
      },
      {
        errors => 2.9e-06,
        participant => "Text::Table",
        rate => 390,
        samples => 20,
        time => 2.6,
        vs_slowest => 20,
      },
      {
        errors => 5.2e-06,
        participant => "Text::Table::TinyColor",
        rate => 390,
        samples => 20,
        time => 2.5,
        vs_slowest => 21,
      },
      {
        errors => 1.8e-06,
        participant => "Text::Table::CSV",
        rate => 1300,
        samples => 21,
        time => 0.77,
        vs_slowest => 68,
      },
      {
        errors => 4.8e-07,
        participant => "Text::Table::Org",
        rate => 1590,
        samples => 20,
        time => 0.628,
        vs_slowest => 83.3,
      },
      {
        errors => 2.1e-07,
        participant => "Text::Table::Tiny",
        rate => 1820,
        samples => 20,
        time => 0.549,
        vs_slowest => 95.2,
      },
    ],
    {
      "func.bencher_args"    => {
                                  action => "bench",
                                  note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                  scenario_module => "TextTableModules",
                                },
      "func.bencher_version" => undef,
      "func.cpu_info"        => [
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 0,
                                    speed                        => 2926.835,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 1,
                                    speed                        => 2900.921,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 2,
                                    speed                        => 2283.464,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 3,
                                    speed                        => 2779.343,
                                    stepping                     => 7,
                                  },
                                ],
      "func.elapsed_time"    => 28.1816189289093,
      "func.module_startup"  => undef,
      "func.module_versions" => {
                                  "Bencher::Scenario::TextTableModules" => undef,
                                  "Benchmark::Dumb"                     => "0.10",
                                  "Devel::Platform::Info"               => 0.16,
                                  "perl"                                => "v5.24.0",
                                  "Sys::Info"                           => 0.78,
                                  "Sys::Load"                           => 0.2,
                                  "Text::ANSITable"                     => 0.48,
                                  "Text::ASCIITable"                    => "0.20",
                                  "Text::FormatTable"                   => 1.03,
                                  "Text::MarkdownTable"                 => "0.3.1",
                                  "Text::Table"                         => 1.131,
                                  "Text::Table::CSV"                    => 0.01,
                                  "Text::Table::Org"                    => 0.02,
                                  "Text::Table::Tiny"                   => 0.04,
                                  "Text::Table::TinyColor"              => 0.002,
                                  "Text::Table::TinyColorWide"          => 0.001,
                                  "Text::Table::TinyWide"               => 0.001,
                                  "Text::TabularDisplay"                => 1.38,
                                },
      "func.note"            => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"         => ["participant", [0 .. 11], "perl", ["perl"]],
      "func.platform_info"   => {
                                  archname => "x86_64",
                                  codename => "jessie",
                                  is32bit  => 0,
                                  is64bit  => 1,
                                  kernel   => "linux-3.16.0-4-amd64",
                                  kname    => "Linux",
                                  kvers    => "3.16.0-4-amd64",
                                  osflag   => "linux",
                                  oslabel  => "Debian",
                                  osname   => "GNU/Linux",
                                  osvers   => "8.0",
                                  source   => {
                                                "cat /etc/.issue" => "",
                                                "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
                                                "uname -m"        => "x86_64",
                                                "uname -o"        => "GNU/Linux",
                                                "uname -r"        => "3.16.0-4-amd64",
                                                "uname -s"        => "Linux",
                                              },
                                },
      "func.precision"       => 0,
      "func.scenario_module" => "Bencher::Scenario::TextTableModules",
      "func.sysload_after"   => [1.02, 0.65, 0.6],
      "func.sysload_before"  => [0.82, 0.57, 0.57],
      "func.time_end"        => 1476889054.92332,
      "func.time_factor"     => 1000,
      "func.time_start"      => 1476889026.7417,
      "table.field_aligns"   => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"    => [undef, "/s", "ms"],
      "table.fields"         => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors => 2.7e-06,
        participant => "Text::ANSITable",
        rate => 770,
        samples => 21,
        time => 1300,
        vs_slowest => 1,
      },
      {
        errors => 2.1e-07,
        participant => "Text::ASCIITable",
        rate => 1940,
        samples => 20,
        time => 514,
        vs_slowest => 2.54,
      },
      {
        errors => 4.3e-07,
        participant => "Text::Table::TinyColorWide",
        rate => 4400,
        samples => 20,
        time => 230,
        vs_slowest => 5.7,
      },
      {
        errors => 1.6e-07,
        participant => "Text::FormatTable",
        rate => 4460,
        samples => 20,
        time => 224,
        vs_slowest => 5.83,
      },
      {
        errors => 1.6e-10,
        participant => "Text::Table",
        rate => 5728.87,
        samples => 21,
        time => 174.554,
        vs_slowest => 7.48586,
      },
      {
        errors => 5.3e-08,
        participant => "Text::Table::TinyWide",
        rate => 6120,
        samples => 20,
        time => 163,
        vs_slowest => 8,
      },
      {
        errors => 5.3e-08,
        participant => "Text::TabularDisplay",
        rate => 8340,
        samples => 20,
        time => 120,
        vs_slowest => 10.9,
      },
      {
        errors => 1.6e-07,
        participant => "Text::MarkdownTable",
        rate => 9000,
        samples => 20,
        time => 110,
        vs_slowest => 12,
      },
      {
        errors => 2.7e-08,
        participant => "Text::Table::TinyColor",
        rate => 15300,
        samples => 20,
        time => 65.3,
        vs_slowest => 20,
      },
      {
        errors => 9.8e-08,
        participant => "Text::Table::Org",
        rate => 39000,
        samples => 21,
        time => 25,
        vs_slowest => 52,
      },
      {
        errors => 2e-08,
        participant => "Text::Table::Tiny",
        rate => 41200,
        samples => 20,
        time => 24.3,
        vs_slowest => 53.8,
      },
      {
        errors => 3.3e-08,
        participant => "Text::Table::CSV",
        rate => 52000,
        samples => 20,
        time => 19,
        vs_slowest => 68,
      },
    ],
    {
      "func.bencher_args"    => {
                                  action => "bench",
                                  note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                  scenario_module => "TextTableModules",
                                },
      "func.bencher_version" => undef,
      "func.cpu_info"        => [
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 0,
                                    speed                        => 2926.835,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 1,
                                    speed                        => 2900.921,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 2,
                                    speed                        => 2283.464,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 3,
                                    speed                        => 2779.343,
                                    stepping                     => 7,
                                  },
                                ],
      "func.elapsed_time"    => 28.1816189289093,
      "func.module_startup"  => undef,
      "func.module_versions" => {
                                  "Bencher::Scenario::TextTableModules" => undef,
                                  "Benchmark::Dumb"                     => "0.10",
                                  "Devel::Platform::Info"               => 0.16,
                                  "perl"                                => "v5.24.0",
                                  "Sys::Info"                           => 0.78,
                                  "Sys::Load"                           => 0.2,
                                  "Text::ANSITable"                     => 0.48,
                                  "Text::ASCIITable"                    => "0.20",
                                  "Text::FormatTable"                   => 1.03,
                                  "Text::MarkdownTable"                 => "0.3.1",
                                  "Text::Table"                         => 1.131,
                                  "Text::Table::CSV"                    => 0.01,
                                  "Text::Table::Org"                    => 0.02,
                                  "Text::Table::Tiny"                   => 0.04,
                                  "Text::Table::TinyColor"              => 0.002,
                                  "Text::Table::TinyColorWide"          => 0.001,
                                  "Text::Table::TinyWide"               => 0.001,
                                  "Text::TabularDisplay"                => 1.38,
                                },
      "func.note"            => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"         => ["participant", [0 .. 11], "perl", ["perl"]],
      "func.platform_info"   => {
                                  archname => "x86_64",
                                  codename => "jessie",
                                  is32bit  => 0,
                                  is64bit  => 1,
                                  kernel   => "linux-3.16.0-4-amd64",
                                  kname    => "Linux",
                                  kvers    => "3.16.0-4-amd64",
                                  osflag   => "linux",
                                  oslabel  => "Debian",
                                  osname   => "GNU/Linux",
                                  osvers   => "8.0",
                                  source   => {
                                                "cat /etc/.issue" => "",
                                                "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
                                                "uname -m"        => "x86_64",
                                                "uname -o"        => "GNU/Linux",
                                                "uname -r"        => "3.16.0-4-amd64",
                                                "uname -s"        => "Linux",
                                              },
                                },
      "func.precision"       => 0,
      "func.scenario_module" => "Bencher::Scenario::TextTableModules",
      "func.sysload_after"   => [1.02, 0.65, 0.6],
      "func.sysload_before"  => [0.82, 0.57, 0.57],
      "func.time_end"        => 1476889054.92332,
      "func.time_factor"     => 1000000,
      "func.time_start"      => 1476889026.7417,
      "table.field_aligns"   => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"    => [undef, "/s", "\x{3BC}s"],
      "table.fields"         => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors => 4.3e-07,
        participant => "Text::ANSITable",
        rate => 3200,
        samples => 20,
        time => 320,
        vs_slowest => 1,
      },
      {
        errors => 2.1e-07,
        participant => "Text::ASCIITable",
        rate => 8000,
        samples => 20,
        time => 120,
        vs_slowest => 2.5,
      },
      {
        errors => 2.7e-08,
        participant => "Text::Table",
        rate => 15100,
        samples => 20,
        time => 66.1,
        vs_slowest => 4.78,
      },
      {
        errors => 2.5e-08,
        participant => "Text::MarkdownTable",
        rate => 17900,
        samples => 23,
        time => 55.8,
        vs_slowest => 5.67,
      },
      {
        errors => 1.3e-08,
        participant => "Text::FormatTable",
        rate => 21400,
        samples => 20,
        time => 46.7,
        vs_slowest => 6.78,
      },
      {
        errors => 5.3e-08,
        participant => "Text::Table::TinyColorWide",
        rate => 26000,
        samples => 20,
        time => 38,
        vs_slowest => 8.2,
      },
      {
        errors => 5.3e-08,
        participant => "Text::Table::TinyWide",
        rate => 32000,
        samples => 20,
        time => 31,
        vs_slowest => 10,
      },
      {
        errors => 5.2e-08,
        participant => "Text::TabularDisplay",
        rate => 33000,
        samples => 21,
        time => 30,
        vs_slowest => 10,
      },
      {
        errors => 2.7e-08,
        participant => "Text::Table::TinyColor",
        rate => 54000,
        samples => 20,
        time => 19,
        vs_slowest => 17,
      },
      {
        errors => 1e-08,
        participant => "Text::Table::Tiny",
        rate => 80900,
        samples => 20,
        time => 12.4,
        vs_slowest => 25.6,
      },
      {
        errors => 1.3e-08,
        participant => "Text::Table::Org",
        rate => 86000,
        samples => 20,
        time => 12,
        vs_slowest => 27,
      },
      {
        errors => 6.5e-09,
        participant => "Text::Table::CSV",
        rate => 170000,
        samples => 21,
        time => 5.9,
        vs_slowest => 53,
      },
    ],
    {
      "func.bencher_args"    => {
                                  action => "bench",
                                  note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                  scenario_module => "TextTableModules",
                                },
      "func.bencher_version" => undef,
      "func.cpu_info"        => [
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 0,
                                    speed                        => 2926.835,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 1,
                                    speed                        => 2900.921,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 2,
                                    speed                        => 2283.464,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 3,
                                    speed                        => 2779.343,
                                    stepping                     => 7,
                                  },
                                ],
      "func.elapsed_time"    => 28.1816189289093,
      "func.module_startup"  => undef,
      "func.module_versions" => {
                                  "Bencher::Scenario::TextTableModules" => undef,
                                  "Benchmark::Dumb"                     => "0.10",
                                  "Devel::Platform::Info"               => 0.16,
                                  "perl"                                => "v5.24.0",
                                  "Sys::Info"                           => 0.78,
                                  "Sys::Load"                           => 0.2,
                                  "Text::ANSITable"                     => 0.48,
                                  "Text::ASCIITable"                    => "0.20",
                                  "Text::FormatTable"                   => 1.03,
                                  "Text::MarkdownTable"                 => "0.3.1",
                                  "Text::Table"                         => 1.131,
                                  "Text::Table::CSV"                    => 0.01,
                                  "Text::Table::Org"                    => 0.02,
                                  "Text::Table::Tiny"                   => 0.04,
                                  "Text::Table::TinyColor"              => 0.002,
                                  "Text::Table::TinyColorWide"          => 0.001,
                                  "Text::Table::TinyWide"               => 0.001,
                                  "Text::TabularDisplay"                => 1.38,
                                },
      "func.note"            => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"         => ["participant", [0 .. 11], "perl", ["perl"]],
      "func.platform_info"   => {
                                  archname => "x86_64",
                                  codename => "jessie",
                                  is32bit  => 0,
                                  is64bit  => 1,
                                  kernel   => "linux-3.16.0-4-amd64",
                                  kname    => "Linux",
                                  kvers    => "3.16.0-4-amd64",
                                  osflag   => "linux",
                                  oslabel  => "Debian",
                                  osname   => "GNU/Linux",
                                  osvers   => "8.0",
                                  source   => {
                                                "cat /etc/.issue" => "",
                                                "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
                                                "uname -m"        => "x86_64",
                                                "uname -o"        => "GNU/Linux",
                                                "uname -r"        => "3.16.0-4-amd64",
                                                "uname -s"        => "Linux",
                                              },
                                },
      "func.precision"       => 0,
      "func.scenario_module" => "Bencher::Scenario::TextTableModules",
      "func.sysload_after"   => [1.02, 0.65, 0.6],
      "func.sysload_before"  => [0.82, 0.57, 0.57],
      "func.time_end"        => 1476889054.92332,
      "func.time_factor"     => 1000000,
      "func.time_start"      => 1476889026.7417,
      "table.field_aligns"   => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"    => [undef, "/s", "\x{3BC}s"],
      "table.fields"         => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
  [
    200,
    "OK",
    [
      {
        errors => 1.1e-05,
        participant => "Text::ANSITable",
        rate => 94.6,
        samples => 20,
        time => 10.6,
        vs_slowest => 1,
      },
      {
        errors => 1.1e-05,
        participant => "Text::ASCIITable",
        rate => 210,
        samples => 20,
        time => 4.8,
        vs_slowest => 2.2,
      },
      {
        errors => 3.2e-06,
        participant => "Text::FormatTable",
        rate => 480,
        samples => 21,
        time => 2.1,
        vs_slowest => 5.1,
      },
      {
        errors => 2.2e-06,
        participant => "Text::Table::TinyColorWide",
        rate => 490,
        samples => 20,
        time => 2,
        vs_slowest => 5.2,
      },
      {
        errors => 2.6e-06,
        participant => "Text::Table::TinyWide",
        rate => 710,
        samples => 24,
        time => 1.4,
        vs_slowest => 7.5,
      },
      {
        errors => 1.2e-06,
        participant => "Text::Table",
        rate => 801,
        samples => 22,
        time => 1.25,
        vs_slowest => 8.47,
      },
      {
        errors => 1.3e-06,
        participant => "Text::TabularDisplay",
        rate => 1400,
        samples => 20,
        time => 0.72,
        vs_slowest => 15,
      },
      {
        errors => 9e-07,
        participant => "Text::Table::TinyColor",
        rate => 2100,
        samples => 28,
        time => 0.48,
        vs_slowest => 22,
      },
      {
        errors => 2.6e-07,
        participant => "Text::MarkdownTable",
        rate => 2680,
        samples => 21,
        time => 0.372,
        vs_slowest => 28.4,
      },
      {
        errors => 2.7e-07,
        participant => "Text::Table::Org",
        rate => 7200,
        samples => 20,
        time => 0.14,
        vs_slowest => 76,
      },
      {
        errors => 4.2e-08,
        participant => "Text::Table::Tiny",
        rate => 8120,
        samples => 33,
        time => 0.123,
        vs_slowest => 85.9,
      },
      {
        errors => 5.2e-08,
        participant => "Text::Table::CSV",
        rate => 8900,
        samples => 21,
        time => 0.112,
        vs_slowest => 94.1,
      },
    ],
    {
      "func.bencher_args"    => {
                                  action => "bench",
                                  note => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
                                  scenario_module => "TextTableModules",
                                },
      "func.bencher_version" => undef,
      "func.cpu_info"        => [
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 0,
                                    speed                        => 2926.835,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 1,
                                    speed                        => 2900.921,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 2,
                                    speed                        => 2283.464,
                                    stepping                     => 7,
                                  },
                                  {
                                    address_width                => 64,
                                    architecture                 => "AMD-64",
                                    bus_speed                    => undef,
                                    data_width                   => 64,
                                    family                       => 6,
                                    flags                        => [
                                                                      "fpu",
                                                                      "vme",
                                                                      "de",
                                                                      "pse",
                                                                      "tsc",
                                                                      "msr",
                                                                      "pae",
                                                                      "mce",
                                                                      "cx8",
                                                                      "apic",
                                                                      "sep",
                                                                      "mtrr",
                                                                      "pge",
                                                                      "mca",
                                                                      "cmov",
                                                                      "pat",
                                                                      "pse36",
                                                                      "clflush",
                                                                      "dts",
                                                                      "acpi",
                                                                      "mmx",
                                                                      "fxsr",
                                                                      "sse",
                                                                      "sse2",
                                                                      "ss",
                                                                      "ht",
                                                                      "tm",
                                                                      "pbe",
                                                                      "syscall",
                                                                      "nx",
                                                                      "rdtscp",
                                                                      "lm",
                                                                      "constant_tsc",
                                                                      "arch_perfmon",
                                                                      "pebs",
                                                                      "bts",
                                                                      "rep_good",
                                                                      "nopl",
                                                                      "xtopology",
                                                                      "nonstop_tsc",
                                                                      "aperfmperf",
                                                                      "eagerfpu",
                                                                      "pni",
                                                                      "pclmulqdq",
                                                                      "dtes64",
                                                                      "monitor",
                                                                      "ds_cpl",
                                                                      "vmx",
                                                                      "smx",
                                                                      "est",
                                                                      "tm2",
                                                                      "ssse3",
                                                                      "cx16",
                                                                      "xtpr",
                                                                      "pdcm",
                                                                      "pcid",
                                                                      "sse4_1",
                                                                      "sse4_2",
                                                                      "x2apic",
                                                                      "popcnt",
                                                                      "tsc_deadline_timer",
                                                                      "aes",
                                                                      "xsave",
                                                                      "avx",
                                                                      "lahf_lm",
                                                                      "ida",
                                                                      "arat",
                                                                      "epb",
                                                                      "xsaveopt",
                                                                      "pln",
                                                                      "pts",
                                                                      "dtherm",
                                                                      "tpr_shadow",
                                                                      "vnmi",
                                                                      "flexpriority",
                                                                      "ept",
                                                                      "vpid",
                                                                    ],
                                    L2_cache                     => { max_cache_size => "6144 KB" },
                                    manufacturer                 => "GenuineIntel",
                                    model                        => 42,
                                    name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
                                    number_of_cores              => 4,
                                    number_of_logical_processors => 4,
                                    processor_id                 => 3,
                                    speed                        => 2779.343,
                                    stepping                     => 7,
                                  },
                                ],
      "func.elapsed_time"    => 28.1816189289093,
      "func.module_startup"  => undef,
      "func.module_versions" => {
                                  "Bencher::Scenario::TextTableModules" => undef,
                                  "Benchmark::Dumb"                     => "0.10",
                                  "Devel::Platform::Info"               => 0.16,
                                  "perl"                                => "v5.24.0",
                                  "Sys::Info"                           => 0.78,
                                  "Sys::Load"                           => 0.2,
                                  "Text::ANSITable"                     => 0.48,
                                  "Text::ASCIITable"                    => "0.20",
                                  "Text::FormatTable"                   => 1.03,
                                  "Text::MarkdownTable"                 => "0.3.1",
                                  "Text::Table"                         => 1.131,
                                  "Text::Table::CSV"                    => 0.01,
                                  "Text::Table::Org"                    => 0.02,
                                  "Text::Table::Tiny"                   => 0.04,
                                  "Text::Table::TinyColor"              => 0.002,
                                  "Text::Table::TinyColorWide"          => 0.001,
                                  "Text::Table::TinyWide"               => 0.001,
                                  "Text::TabularDisplay"                => 1.38,
                                },
      "func.note"            => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
      "func.permute"         => ["participant", [0 .. 11], "perl", ["perl"]],
      "func.platform_info"   => {
                                  archname => "x86_64",
                                  codename => "jessie",
                                  is32bit  => 0,
                                  is64bit  => 1,
                                  kernel   => "linux-3.16.0-4-amd64",
                                  kname    => "Linux",
                                  kvers    => "3.16.0-4-amd64",
                                  osflag   => "linux",
                                  oslabel  => "Debian",
                                  osname   => "GNU/Linux",
                                  osvers   => "8.0",
                                  source   => {
                                                "cat /etc/.issue" => "",
                                                "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
                                                "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
                                                "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.7-ckt7-1 (2015-03-01) x86_64 GNU/Linux",
                                                "uname -m"        => "x86_64",
                                                "uname -o"        => "GNU/Linux",
                                                "uname -r"        => "3.16.0-4-amd64",
                                                "uname -s"        => "Linux",
                                              },
                                },
      "func.precision"       => 0,
      "func.scenario_module" => "Bencher::Scenario::TextTableModules",
      "func.sysload_after"   => [1.02, 0.65, 0.6],
      "func.sysload_before"  => [0.82, 0.57, 0.57],
      "func.time_end"        => 1476889054.92332,
      "func.time_factor"     => 1000,
      "func.time_start"      => 1476889026.7417,
      "table.field_aligns"   => ["left", "number", "number", "number", "number", "number"],
      "table.field_units"    => [undef, "/s", "ms"],
      "table.fields"         => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
    },
  ],
];

1;
# ABSTRACT: Benchmark modules that generate text table

=head1 DESCRIPTION

This module is automatically generated by Pod::Weaver::Plugin::Bencher::Scenario during distribution build.

A Bencher::ScenarioR::* module contains the raw result of sample benchmark and might be useful for some stuffs later.

